export class Utilities {
    static capitalize(string) {
        return string.charAt(0).toUpperCase() + string.slice(1);
    }
    static base64url(string) {
        return btoa(string).replace(/\+/g, '-').replace(/\//g, '_').replace(/\=+$/, '');
    }
    static urlencode(string) {
        return encodeURIComponent(string)
            .replace(/['()]/g, escape)
            .replace(/\*/g, '%2A')
            .replace(/%(?:7C|60|5E)/g, unescape);
    }
    static dec2hex(dec) {
        return dec.toString(16).padStart(2, '0');
    }
    static parseJwt(token) {
        var base64Url = token.split('.')[1];
        var base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');
        var jsonPayload = decodeURIComponent(atob(base64)
            .split('')
            .map(function (c) {
            return '%' + ('00' + c.charCodeAt(0).toString(16)).slice(-2);
        })
            .join(''));
        return JSON.parse(jsonPayload);
    }
    static uniqueFilter(value, index, self) {
        return self.indexOf(value) === index;
    }
    static parseLinks(text) {
        var urls = [];
        const matches = text.matchAll(/([*~_]+|\b)(((https?|ftp|dict):\/\/|www\.)[^'">\s]+\.[^'">\s]+?)([.!?,()\[\]])?(\1)?(?=\s|$)(?!["<>])/gi);
        for (const match of matches) {
            urls.push(match[0]);
        }
        return urls.filter(this.uniqueFilter);
    }
    static buildMessage(user, message) {
        if (user && message) {
            if (message.kind === 'poke' || message.kind === 'message') {
                const newMessage = {
                    fromId: user.id,
                    fromName: user.name,
                    fromAvatar: user.avatar,
                    kind: message.kind,
                    text: message.payload.text,
                    urls: this.parseLinks(message.payload.text),
                    time: new Date()
                };
                if (message.isPrivate) {
                    newMessage.isPrivate = message.isPrivate;
                }
                return newMessage;
            }
        }
        return null;
    }
    static createUserFromUserData(userData, peerId) {
        return {
            id: userData.id ? userData.id : '',
            name: userData.name ? userData.name : 'Unknown',
            avatar: userData.avatar,
            peerId: peerId,
            status: userData.status ? userData.status : 'online',
            outputMuted: userData.outputMuted ? userData.outputMuted : 0,
            inputMuted: 1,
            renderer: userData.renderer ? userData.renderer : '',
            platform: userData.platform ? userData.platform : '',
            revision: userData.revision ? userData.revision : '',
            version: userData.version ? userData.version : '',
            buildno: userData.buildno ? userData.buildno : 0
        };
    }
    static userDataFromUser(user) {
        const userData = {};
        userData.id = user.id;
        userData.avatar = user.avatar;
        userData.name = user.name;
        userData.status = user.status;
        userData.outputMuted = user.outputMuted;
        userData.renderer = user.renderer;
        userData.revision = user.revision;
        userData.version = user.version;
        userData.platform = user.platform;
        userData.buildno = user.buildno;
        return userData;
    }
    static encodeObjToUint8Array(data) {
        return new TextEncoder().encode(JSON.stringify(data));
    }
    static decodeUint8ArrayToObject(data) {
        if (data.length === 0)
            return {};
        return JSON.parse(new TextDecoder().decode(data));
    }
}
